@@ -1,15 +1,20 @@
 package Wx::Scintilla;
 
-
 use strict;
 use warnings;
 use Wx;
+use Carp;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # Define Perl 6 lexer
 use constant wxSCINTILLA_LEX_PERL6 => 98;
 
+# check for loaded Wx::STC
+if ( exists( $INC{'Wx/STC.pm'} ) ) {
+	croak('Wx::Scintilla cannot be loaded alongside Wx::STC. Choose one and only one of the modules. ');
+}
+
 require XSLoader;
 XSLoader::load 'Wx::Scintilla', $VERSION;
 
@@ -20,17 +25,17 @@ XSLoader::load 'Wx::Scintilla', $VERSION;
 no strict;
 
 package Wx::ScintillaTextCtrl;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 @ISA = qw(Wx::Control);
 
 package Wx::ScintillaTextEvent;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 @ISA = qw(Wx::CommandEvent);
 
 #Defeat the indexer by splitting the package declaration on two lines
 #<<<  do not let perltidy touch this
 package
-	Wx::Event;
+    Wx::Event;
 # Don't set global Wx::Event version
 #>>>
 
@@ -81,88 +86,88 @@ Wx::Scintilla - wxWidgets Perl XS wrapper for the Scintilla editor component
 
 =head1 SYNOPSIS
 
-	#----> My first scintilla Wx editor :)
-	package My::Scintilla::Editor;
+    #----> My first scintilla Wx editor :)
+    package My::Scintilla::Editor;
 
-	use strict;
-	use warnings;
+    use strict;
+    use warnings;
 
-	# Load Wx::Scintilla
-	use Wx::Scintilla ();    # replaces use Wx::STC
-	use base 'Wx::ScintillaTextCtrl';    # replaces Wx::StyledTextCtrl
+    # Load Wx::Scintilla
+    use Wx::Scintilla ();    # replaces use Wx::STC
+    use base 'Wx::ScintillaTextCtrl';    # replaces Wx::StyledTextCtrl
 
-	use Wx qw(:everything);
-	use Wx::Event;
+    use Wx qw(:everything);
+    use Wx::Event;
 
-	# Override the constructor to Enable Perl support in the editor
-	sub new {
-		my ( $class, $parent ) = @_;
-		my $self = $class->SUPER::new( $parent, -1, [ -1, -1 ], [ 750, 700 ] );
+    # Override the constructor to Enable Perl support in the editor
+    sub new {
+        my ( $class, $parent ) = @_;
+        my $self = $class->SUPER::new( $parent, -1, [ -1, -1 ], [ 750, 700 ] );
 
-		# Set the font
-		my $font = Wx::Font->new( 10, wxTELETYPE, wxNORMAL, wxNORMAL );
-		$self->SetFont($font);
-		$self->StyleSetFont( wxSTC_STYLE_DEFAULT, $font );
-		$self->StyleClearAll();
+        # Set the font
+        my $font = Wx::Font->new( 10, wxTELETYPE, wxNORMAL, wxNORMAL );
+        $self->SetFont($font);
+        $self->StyleSetFont( wxSTC_STYLE_DEFAULT, $font );
+        $self->StyleClearAll();
 
-		# Set the various Perl lexer colors
-		$self->StyleSetForeground( 0,  Wx::Colour->new( 0x00, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 1,  Wx::Colour->new( 0xff, 0x00, 0x00 ) );
-		$self->StyleSetForeground( 2,  Wx::Colour->new( 0x00, 0x7f, 0x00 ) );
-		$self->StyleSetForeground( 3,  Wx::Colour->new( 0x7f, 0x7f, 0x7f ) );
-		$self->StyleSetForeground( 4,  Wx::Colour->new( 0x00, 0x7f, 0x7f ) );
-		$self->StyleSetForeground( 5,  Wx::Colour->new( 0x00, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 6,  Wx::Colour->new( 0xff, 0x7f, 0x00 ) );
-		$self->StyleSetForeground( 7,  Wx::Colour->new( 0x7f, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 8,  Wx::Colour->new( 0x00, 0x00, 0x00 ) );
-		$self->StyleSetForeground( 9,  Wx::Colour->new( 0x7f, 0x7f, 0x7f ) );
-		$self->StyleSetForeground( 10, Wx::Colour->new( 0x00, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 11, Wx::Colour->new( 0x00, 0x00, 0xff ) );
-		$self->StyleSetForeground( 12, Wx::Colour->new( 0x7f, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 13, Wx::Colour->new( 0x40, 0x80, 0xff ) );
-		$self->StyleSetForeground( 17, Wx::Colour->new( 0xff, 0x00, 0x7f ) );
-		$self->StyleSetForeground( 18, Wx::Colour->new( 0x7f, 0x7f, 0x00 ) );
-		$self->StyleSetBold( 12, 1 );
-		$self->StyleSetSpec( wxSTC_H_TAG, "fore:#0000ff" );
+        # Set the various Perl lexer colors
+        $self->StyleSetForeground( 0,  Wx::Colour->new( 0x00, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 1,  Wx::Colour->new( 0xff, 0x00, 0x00 ) );
+        $self->StyleSetForeground( 2,  Wx::Colour->new( 0x00, 0x7f, 0x00 ) );
+        $self->StyleSetForeground( 3,  Wx::Colour->new( 0x7f, 0x7f, 0x7f ) );
+        $self->StyleSetForeground( 4,  Wx::Colour->new( 0x00, 0x7f, 0x7f ) );
+        $self->StyleSetForeground( 5,  Wx::Colour->new( 0x00, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 6,  Wx::Colour->new( 0xff, 0x7f, 0x00 ) );
+        $self->StyleSetForeground( 7,  Wx::Colour->new( 0x7f, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 8,  Wx::Colour->new( 0x00, 0x00, 0x00 ) );
+        $self->StyleSetForeground( 9,  Wx::Colour->new( 0x7f, 0x7f, 0x7f ) );
+        $self->StyleSetForeground( 10, Wx::Colour->new( 0x00, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 11, Wx::Colour->new( 0x00, 0x00, 0xff ) );
+        $self->StyleSetForeground( 12, Wx::Colour->new( 0x7f, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 13, Wx::Colour->new( 0x40, 0x80, 0xff ) );
+        $self->StyleSetForeground( 17, Wx::Colour->new( 0xff, 0x00, 0x7f ) );
+        $self->StyleSetForeground( 18, Wx::Colour->new( 0x7f, 0x7f, 0x00 ) );
+        $self->StyleSetBold( 12, 1 );
+        $self->StyleSetSpec( wxSTC_H_TAG, "fore:#0000ff" );
 
-		# set the lexer to Perl 5
-		$self->SetLexer(wxSTC_LEX_PERL);
+        # set the lexer to Perl 5
+        $self->SetLexer(wxSTC_LEX_PERL);
 
-		return $self;
-	}
+        return $self;
+    }
 
-	#----> DEMO EDITOR APPLICATION
+    #----> DEMO EDITOR APPLICATION
 
-	# First, define an application object class to encapsulate the application itself
-	package DemoEditorApp;
+    # First, define an application object class to encapsulate the application itself
+    package DemoEditorApp;
 
-	use strict;
-	use warnings;
-	use Wx;
-	use base 'Wx::App';
+    use strict;
+    use warnings;
+    use Wx;
+    use base 'Wx::App';
 
-	# We must override OnInit to build the window
-	sub OnInit {
-		my $self = shift;
+    # We must override OnInit to build the window
+    sub OnInit {
+        my $self = shift;
 
-		my $frame = Wx::Frame->new(
-		undef,                           # no parent window
-		-1,                              # no window id
-		'My First Scintilla Editor!',    # Window title
-		);
+        my $frame = Wx::Frame->new(
+        undef,                           # no parent window
+        -1,                              # no window id
+        'My First Scintilla Editor!',    # Window title
+        );
 
-		my $editor = My::Scintilla::Editor->new(
-		$frame,                          # Parent window
-		);
+        my $editor = My::Scintilla::Editor->new(
+        $frame,                          # Parent window
+        );
 
-		$frame->Show(1);
-		return 1;
-	}
+        $frame->Show(1);
+        return 1;
+    }
 
-	# Create the application object, and pass control to it.
-	package main;
-	my $app = DemoEditorApp->new;
-	$app->MainLoop;
+    # Create the application object, and pass control to it.
+    package main;
+    my $app = DemoEditorApp->new;
+    $app->MainLoop;
 
 
 =head1 DESCRIPTION
@@ -180,6 +185,10 @@ The ambitious goal of this project is to provide fresh Perl 5 and maybe 6
 support in L<Wx> while preserving compatibility with Wx::StyledTextCtrl
 and continually contribute it back to Scintilla project.
 
+Note: You cannot load Wx::STC and Wx::Scintilla in the same application. They
+are mutually exclusive. The wxSTC_... events are handled by one library or
+the other.
+
 =head1 MANUAL
 
 If you are looking for more API documentation, please consult L<Wx::Scintilla::Manual>
@@ -192,7 +201,7 @@ platforms. Please let me know if you can help out :)
 
 On Debian/Ubuntu, you need to install the following via:
 
-	sudo apt-get install libgtk2.0-dev
+    sudo apt-get install libgtk2.0-dev
 
 On MacOS 64-bit by default you need to install a 32-bit Perl in order to
 install wxWidgets 2.8.x. Please refer to 
